导入 jieba

套路 分词(语句, 全模式=假, HMM=真, 使用飞浆=假):
    """
    主要函数, 将包含中文字符的整句分割成单独的词汇. 返回一个生成器.

    '全模式' 默认为假, 即使用精确模式.
    """
    生成 自 jieba.cut(语句, cut_all=全模式, HMM=HMM, use_paddle=使用飞浆)

套路 分词列表(*参数, **关键词参数):
    """
    '分词' 函数的返回列表版本.
    """
    返回 jieba.lcut(*参数, **关键词参数)

套路 分词_搜索引擎(语句, HMM=真):
    """
    更精细分词, 用于搜索引擎. 返回一个生成器.
    """
    生成 自 jieba.cut_for_search(语句, HMM=HMM)

套路 分词列表_搜索引擎(*参数, **关键词参数):
    """
    '分词_搜索引擎' 函数的返回列表版本.
    """
    返回 jieba.lcut_for_search(*参数, **关键词参数)

套路 添加词语(词语, 词频=空, 词性=空):
    """
    添加一个词语到字典.

    '词频' 和 '词性' 可忽略.
    '词频' 默认为一个确保该词可被切分的计算值.
    """
    jieba.add_word(词语, freq=词频, tag=词性)

套路 删除词语(词语):
    """
    删除词语的便利函数.
    """
    jieba.del_word(词语)






"""结巴命令行界面"""
import sys
import jieba
from argparse import ArgumentParser
# from ._compat import *

parser = ArgumentParser(usage="%s -m 结巴 [选项] 文件名" % sys.executable, description="结巴命令行界面.", epilog="若未指定文件名, 则使用标准输入 (STDIN).")
parser.add_argument("-d", "--delimiter", metavar="DELIM", default=' / ',
                    nargs='?', const=' ',
                    help="使用 DELIM 分隔词语，而不是用默认的' / '。若不指定 DELIM，则使用一个空格分隔。")
parser.add_argument("-p", "--pos", metavar="DELIM", nargs='?', const='_',
                    help="启用词性标注；如果指定 DELIM，词语和词性之间用它分隔，否则用 _ 分隔")
parser.add_argument("-D", "--dict", help="使用 DICT 代替默认词典")
parser.add_argument("-u", "--user-dict",
                    help="使用 USER_DICT 作为附加词典，与默认词典或自定义词典配合使用")
parser.add_argument("-a", "--cut-all",
                    action="store_true", dest="cutall", default=False,
                    help="全模式分词（不支持词性标注）")
parser.add_argument("-n", "--no-hmm", dest="hmm", action="store_false",
                    default=True, help="不使用隐含马尔可夫模型")
parser.add_argument("-q", "--quiet", action="store_true", default=False,
                    help="不打印加载消息到错误输出 (stderr)")
parser.add_argument("-V", '--version', action='version',
                    version="Jieba " + jieba.__version__)
parser.add_argument("文件名", nargs='?', help="输入文件")

args = parser.parse_args()

if args.quiet:
    jieba.setLogLevel(60)
if args.pos:
    import jieba.posseg
    posdelim = args.pos
    def cutfunc(sentence, _, HMM=True):
        for w, f in jieba.posseg.cut(sentence, HMM):
            yield w + posdelim + f
else:
    cutfunc = jieba.cut

delim = str(args.delimiter)
cutall = args.cutall
hmm = args.hmm
fp = open(args.文件名, 'r') if args.文件名 else sys.stdin

if args.dict:
    jieba.initialize(args.dict)
else:
    jieba.initialize()
if args.user_dict:
    jieba.load_userdict(args.user_dict)

ln = fp.readline()
while ln:
    l = ln.rstrip('\r\n')
    result = delim.join(cutfunc(ln.rstrip('\r\n'), cutall, hmm))
    # if PY2:
        # result = result.encode(default_encoding)
    print(result)
    ln = fp.readline()

fp.close()
